==> kdepim-addons-16.07.80.tar.xz: kdepim-addons-16.07.80/kmail/editorsendcheckplugins/confirm-address/confirmaddressdialog.h <==
/*
   Copyright (C) 2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CONFIRMADDRESSDIALOG_H
#define CONFIRMADDRESSDIALOG_H

#include <QDialog>
class ConfirmAddressWidget;
class ConfirmAddressDialog : public QDialog
{
    Q_OBJECT
public:
    explicit ConfirmAddressDialog(QWidget *parent = Q_NULLPTR);
    ~ConfirmAddressDialog();

    void setValidAddresses(const QStringList &addresses);
    void setInvalidAddresses(const QStringList &addresses);
    void setCurrentIdentity(uint identity);

Q_SIGNALS:
    void addWhileListEmails(const QStringList &, uint currentIdentity);

private:
    void slotWhiteListSelectedEmails();
    void writeConfig();
    void readConfig();
    uint mCurrentIdentity;
    ConfirmAddressWidget *mConfirmWidget;
};

#endif // CONFIRMADDRESSDIALOG_H

==> kdepim-addons-17.08.0.tar.xz: kdepim-addons-17.08.0/kmail/editorsendcheckplugins/confirm-address/confirmaddressdialog.h <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CONFIRMADDRESSDIALOG_H
#define CONFIRMADDRESSDIALOG_H

#include <QDialog>
class ConfirmAddressWidget;
class ConfirmAddressDialog : public QDialog
{
    Q_OBJECT
public:
    explicit ConfirmAddressDialog(QWidget *parent = nullptr);
    ~ConfirmAddressDialog();

    void setValidAddresses(const QStringList &addresses);
    void setInvalidAddresses(const QStringList &addresses);
    void setCurrentIdentity(uint identity);

Q_SIGNALS:
    void addWhileListEmails(const QStringList &, uint currentIdentity);

private:
    void slotWhiteListSelectedEmails();
    void writeConfig();
    void readConfig();
    uint mCurrentIdentity;
    ConfirmAddressWidget *mConfirmWidget;
    QPushButton *mWhiteListEmailsButton;
};

#endif // CONFIRMADDRESSDIALOG_H
